You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [9/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AuthorizationAttributeSourceAdvisor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AuthorizationAttributeSourceAdvisor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/SpringKiFilterTest.java (original)
+++ incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/SpringKiFilterTest.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring;
+package org.apache.shiro.spring;
 
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.web.servlet.KiFilter;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.web.servlet.ShiroFilter;
 import static org.easymock.EasyMock.*;
 import org.junit.Test;
 import org.springframework.web.context.WebApplicationContext;
@@ -38,18 +38,18 @@
 
     @Test
     public void testDefaultConfig() throws Exception {
-        SpringKiFilter filter = new SpringKiFilter();
+        SpringShiroFilter filter = new SpringShiroFilter();
 
         FilterConfig mockConfig = createMock(FilterConfig.class);
-        expect(mockConfig.getInitParameter(KiFilter.CONFIG_CLASS_NAME_INIT_PARAM_NAME)).andReturn(null);
-        expect(mockConfig.getInitParameter(KiFilter.CONFIG_INIT_PARAM_NAME)).andReturn(null);
-        expect(mockConfig.getInitParameter(KiFilter.CONFIG_URL_INIT_PARAM_NAME)).andReturn(null);
+        expect(mockConfig.getInitParameter(ShiroFilter.CONFIG_CLASS_NAME_INIT_PARAM_NAME)).andReturn(null);
+        expect(mockConfig.getInitParameter(ShiroFilter.CONFIG_INIT_PARAM_NAME)).andReturn(null);
+        expect(mockConfig.getInitParameter(ShiroFilter.CONFIG_URL_INIT_PARAM_NAME)).andReturn(null);
         expect(mockConfig.getInitParameter(SpringIniWebConfiguration.SECURITY_MANAGER_BEAN_NAME_PARAM_NAME)).andReturn(null);
 
         ServletContext mockContext = createMock(ServletContext.class);
         WebApplicationContext appCtx = createMock(WebApplicationContext.class);
         SecurityManager secMgr = createMock(SecurityManager.class);
-        Map<String, org.apache.ki.mgt.SecurityManager> beansOfType = new HashMap<String, SecurityManager>(1);
+        Map<String, org.apache.shiro.mgt.SecurityManager> beansOfType = new HashMap<String, SecurityManager>(1);
         beansOfType.put("securityManager", secMgr);
 
         expect(mockContext.getAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE)).andReturn(appCtx);

Modified: incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactoryTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactoryTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactoryTest.java (original)
+++ incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/remoting/SecureRemoteInvocationFactoryTest.java Thu Jun 18 03:13:34 2009
@@ -1,9 +1,9 @@
-package org.apache.ki.spring.remoting;
+package org.apache.shiro.spring.remoting;
 
 import org.aopalliance.intercept.MethodInvocation;
-import org.apache.ki.session.mgt.SessionManager;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.session.mgt.SessionManager;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 import static org.easymock.EasyMock.*;
 import org.junit.After;
 import static org.junit.Assert.*;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/DefaultWebSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/DefaultWebSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/DefaultWebSecurityManager.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/DefaultWebSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
-import org.apache.ki.mgt.DefaultSecurityManager;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.session.mgt.SessionManager;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.LifecycleUtils;
-import org.apache.ki.web.attr.CookieAttribute;
-import org.apache.ki.web.servlet.KiHttpServletRequest;
-import org.apache.ki.web.session.DefaultWebSessionManager;
-import org.apache.ki.web.session.ServletContainerSessionManager;
-import org.apache.ki.web.session.WebSessionManager;
+import org.apache.shiro.mgt.DefaultSecurityManager;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.session.mgt.SessionManager;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.LifecycleUtils;
+import org.apache.shiro.web.attr.CookieAttribute;
+import org.apache.shiro.web.servlet.ShiroHttpServletRequest;
+import org.apache.shiro.web.session.DefaultWebSessionManager;
+import org.apache.shiro.web.session.ServletContainerSessionManager;
+import org.apache.shiro.web.session.WebSessionManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -50,7 +50,7 @@
     private static final Logger log = LoggerFactory.getLogger(DefaultWebSecurityManager.class);
 
     public static final String HTTP_SESSION_MODE = "http";
-    public static final String KI_SESSION_MODE = "ki";
+    public static final String KI_SESSION_MODE = "shiro";
 
     /**
      * The key that is used to store subject principals in the session.
@@ -155,7 +155,7 @@
             String msg = "The convenience passthrough methods for setting session id cookie attributes " +
                     "are only available when the underlying SessionManager implementation is " +
                     DefaultWebSessionManager.class.getName() + ", which is enabled by default when the " +
-                    "sessionMode is 'ki'.";
+                    "sessionMode is 'shiro'.";
             throw new IllegalStateException(msg);
         }
         return (DefaultWebSessionManager) sessionManager;
@@ -251,7 +251,7 @@
     protected void removeRequestIdentity() {
         ServletRequest request = WebUtils.getServletRequest();
         if (request != null) {
-            request.setAttribute(KiHttpServletRequest.IDENTITY_REMOVED_KEY, Boolean.TRUE);
+            request.setAttribute(ShiroHttpServletRequest.IDENTITY_REMOVED_KEY, Boolean.TRUE);
         }
     }
 }

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/RedirectView.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/RedirectView.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/RedirectView.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/RedirectView.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
@@ -28,7 +28,7 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.util.JavaEnvironment;
+import org.apache.shiro.util.JavaEnvironment;
 
 /**
  * <p>View that redirects to an absolute, context relative, or current request

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/SavedRequest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/SavedRequest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/SavedRequest.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/SavedRequest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
 import java.io.Serializable;
 import javax.servlet.http.HttpServletRequest;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebRememberMeManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebRememberMeManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebSubjectFactory.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebSubjectFactory.java Thu Jun 18 03:13:34 2009
@@ -16,19 +16,19 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
 import java.net.InetAddress;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.mgt.DefaultSubjectFactory;
-import org.apache.ki.mgt.SecurityManager;
-import org.apache.ki.mgt.SessionSubjectBinder;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.session.WebSessionManager;
+import org.apache.shiro.mgt.DefaultSubjectFactory;
+import org.apache.shiro.mgt.SecurityManager;
+import org.apache.shiro.mgt.SessionSubjectBinder;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.session.WebSessionManager;
 
 
 /**

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/AbstractWebAttribute.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/AbstractWebAttribute.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.attr;
+package org.apache.shiro.web.attr;
 
 import java.beans.PropertyEditor;
 import javax.servlet.ServletRequest;
@@ -25,8 +25,8 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.KiException;
-import org.apache.ki.util.ClassUtils;
+import org.apache.shiro.ShiroException;
+import org.apache.shiro.util.ClassUtils;
 
 /**
  * Convenient superclass for implementations of the {@link WebAttribute} interface.  This class encapsulates
@@ -148,7 +148,7 @@
                 return (T) stringValue;
             } catch (Exception e) {
                 String msg = "If the type is not String, you must specify the 'editorClass' property.";
-                throw new KiException(msg, e);
+                throw new ShiroException(msg, e);
             }
         } else {
             PropertyEditor editor = (PropertyEditor) ClassUtils.newInstance(getEditorClass());
@@ -158,7 +158,7 @@
                 return (T) value;
             } catch (ClassCastException e) {
                 String msg = "Returned value from PropertyEditor does not match the specified type.";
-                throw new KiException(msg, e);
+                throw new ShiroException(msg, e);
             }
         }
     }

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/CookieAttribute.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/CookieAttribute.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/CookieAttribute.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/CookieAttribute.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.attr;
+package org.apache.shiro.web.attr;
 
-import org.apache.ki.util.StringUtils;
-import static org.apache.ki.web.WebUtils.toHttp;
+import org.apache.shiro.util.StringUtils;
+import static org.apache.shiro.web.WebUtils.toHttp;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/RequestParamAttribute.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/RequestParamAttribute.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/RequestParamAttribute.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/RequestParamAttribute.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.attr;
+package org.apache.shiro.web.attr;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/WebAttribute.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/WebAttribute.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/WebAttribute.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/WebAttribute.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.attr;
+package org.apache.shiro.web.attr;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathConfigProcessor.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathConfigProcessor.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter;
+package org.apache.shiro.web.filter;
 
 import javax.servlet.Filter;
 

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathMatchingFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathMatchingFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathMatchingFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathMatchingFilter.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter;
+package org.apache.shiro.web.filter;
 
 import java.util.LinkedHashMap;
 import java.util.Map;
@@ -27,11 +27,11 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.util.AntPathMatcher;
-import org.apache.ki.util.PatternMatcher;
-import static org.apache.ki.util.StringUtils.split;
-import org.apache.ki.web.WebUtils;
-import org.apache.ki.web.servlet.AdviceFilter;
+import org.apache.shiro.util.AntPathMatcher;
+import org.apache.shiro.util.PatternMatcher;
+import static org.apache.shiro.util.StringUtils.split;
+import org.apache.shiro.web.WebUtils;
+import org.apache.shiro.web.servlet.AdviceFilter;
 
 /**
  * <p>Base class for Filters that will process only specified paths and allow all others to pass through.</p>

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AnonymousFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AnonymousFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AnonymousFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AnonymousFilter.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.web.filter.PathMatchingFilter;
+import org.apache.shiro.web.filter.PathMatchingFilter;
 
 /**
  * Filter that allows access to a path immeidately without performing security checks of any kind.

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticatingFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticatingFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticatingFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticatingFilter.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import java.net.InetAddress;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.WebUtils;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.WebUtils;
 
 /**
  * An <code>AuthenticationFilter</code> that is capable of automatically performing an authentication attempt
@@ -84,7 +84,7 @@
      * during construction of an <code>AuthenticationToken</code>.
      * <p/>
      * The default implementation merely returns
-     * {@link org.apache.ki.web.WebUtils#getInetAddress(javax.servlet.ServletRequest) WebUtils.getInetAddress(request)}.
+     * {@link org.apache.shiro.web.WebUtils#getInetAddress(javax.servlet.ServletRequest) WebUtils.getInetAddress(request)}.
      *
      * @param request the incoming ServletRequest
      * @return the <code>InetAddress</code> to associate with the login attempt.

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/AuthenticationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.SavedRequest;
-import org.apache.ki.web.WebUtils;
-import org.apache.ki.web.filter.AccessControlFilter;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.SavedRequest;
+import org.apache.shiro.web.WebUtils;
+import org.apache.shiro.web.filter.AccessControlFilter;
 
 /**
  * <p>Base class for all Filters that require the current user to be authenticated. This class encapsulates the
@@ -65,7 +65,7 @@
      * <p/>
      * The default implementation {@link #getSubject(javax.servlet.ServletRequest, javax.servlet.ServletResponse) acquires}
      * the currently executing Subject and then returns
-     * {@link org.apache.ki.subject.Subject#isAuthenticated() subject.isAuthenticated()};
+     * {@link org.apache.shiro.subject.Subject#isAuthenticated() subject.isAuthenticated()};
      *
      * @return true if the subject is authenticated; false if the subject is unauthenticated
      */

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/BasicHttpAuthenticationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/BasicHttpAuthenticationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/FormAuthenticationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/FormAuthenticationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
@@ -25,11 +25,11 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.UsernamePasswordToken;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.WebUtils;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.UsernamePasswordToken;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.WebUtils;
 
 
 /**
@@ -39,7 +39,7 @@
  * <p>This filter constructs a {@link UsernamePasswordToken UsernamePasswordToken} with the values found in
  * {@link #setUsernameParam(String) username}, {@link #setPasswordParam(String) password},
  * and {@link #setRememberMeParam(String) rememberMe} request parameters.  It then calls
- * {@link org.apache.ki.subject.Subject#login(org.apache.ki.authc.AuthenticationToken) Subject.login(usernamePasswordToken)},
+ * {@link org.apache.shiro.subject.Subject#login(org.apache.shiro.authc.AuthenticationToken) Subject.login(usernamePasswordToken)},
  * effectively automatically performing a login attempt.  Note that the login attempt will only occur when the
  * {@link #isLoginSubmission(javax.servlet.ServletRequest, javax.servlet.ServletResponse) isLoginSubmission(request,response)}
  * is <code>true</code>, which by default occurs when the request is for the {@link #setLoginUrl(String) loginUrl} and

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/PassThruAuthenticationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/PassThruAuthenticationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/PassThruAuthenticationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/PassThruAuthenticationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
@@ -30,12 +30,12 @@
  * on a login submission (by default an HTTP POST to the login URL), the <code>FormAuthenticationFilter</code> filter
  * attempts to automatically authenticate the user by passing the <code>username</code> and <code>password</code>
  * request parameter values to
- * {@link org.apache.ki.subject.Subject#login(org.apache.ki.authc.AuthenticationToken) Subject.login(usernamePasswordToken)}
+ * {@link org.apache.shiro.subject.Subject#login(org.apache.shiro.authc.AuthenticationToken) Subject.login(usernamePasswordToken)}
  * directly.
  * <p/>
  * Conversely, this controller always passes all requests to the {@link #setLoginUrl loginUrl} through, both GETs and
  * POSTs.  This is useful in cases where the developer wants to write their own login behavior, which should include a
- * call to {@link org.apache.ki.subject.Subject#login(org.apache.ki.authc.AuthenticationToken) Subject.login(AuthenticationToken)}
+ * call to {@link org.apache.shiro.subject.Subject#login(org.apache.shiro.authc.AuthenticationToken) Subject.login(AuthenticationToken)}
  * at some point.  For example,  if the developer has their own custom MVC login controller or validator,
  * this <code>PassThruAuthenticationFilter</code> may be appropriate.
  *

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/UserFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/UserFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/UserFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/UserFilter.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.filter.AccessControlFilter;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.filter.AccessControlFilter;
 
 /**
  * Filter that allows access to resources if the accessor is a known user, which is defined as

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Servlet {@link javax.servlet.Filter Filter} implementations specific to controlling access based on a
- * subject's authentication status, or those that can execute authentications (log-ins) directly.
- */
-package org.apache.ki.web.filter.authc;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Servlet {@link javax.servlet.Filter Filter} implementations specific to controlling access based on a
+ * subject's authentication status, or those that can execute authentications (log-ins) directly.
+ */
+package org.apache.shiro.web.filter.authc;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/AuthorizationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/AuthorizationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/HostFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/HostFilter.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
-import org.apache.ki.util.StringUtils;
+import org.apache.shiro.util.StringUtils;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PermissionsAuthorizationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PermissionsAuthorizationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PermissionsAuthorizationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PermissionsAuthorizationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
 import java.io.IOException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.subject.Subject;
 
 /**
  * Filter that allows access if the current user has the permissions specified by the mapped value, or denies access

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PortFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PortFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PortFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/PortFilter.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
-import org.apache.ki.config.ConfigurationException;
-import org.apache.ki.util.StringUtils;
-import org.apache.ki.web.WebUtils;
+import org.apache.shiro.config.ConfigurationException;
+import org.apache.shiro.util.StringUtils;
+import org.apache.shiro.web.WebUtils;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/RolesAuthorizationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/RolesAuthorizationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/RolesAuthorizationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/RolesAuthorizationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
 import java.io.IOException;
 import java.util.Set;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.CollectionUtils;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.CollectionUtils;
 
 
 /**

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/SslFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/SslFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/SslFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/SslFilter.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
 /**
  * Convenience filter which requires a request to be over SSL.  This filter has the same effect as of using the

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Servlet {@link javax.servlet.Filter Filter} implementations that perform authorization (access control)
- * checks based on the Subject's abilities (for example, role or permission checks).
- */
-package org.apache.ki.web.filter.authz;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Servlet {@link javax.servlet.Filter Filter} implementations that perform authorization (access control)
+ * checks based on the Subject's abilities (for example, role or permission checks).
+ */
+package org.apache.shiro.web.filter.authz;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,23 +1,23 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Base package supporting all Servlet {@link javax.servlet.Filter Filter} implementations used to control
- * access to web pages and URL resources.
- */
-package org.apache.ki.web.filter;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Base package supporting all Servlet {@link javax.servlet.Filter Filter} implementations used to control
+ * access to web pages and URL resources.
+ */
+package org.apache.shiro.web.filter;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/package-info.java Thu Jun 18 03:13:34 2009
@@ -1,22 +1,22 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-/**
- * Framework support for any web-enabled application.
- */
-package org.apache.ki.web;
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+/**
+ * Framework support for any web-enabled application.
+ */
+package org.apache.shiro.web;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/AdviceFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/AdviceFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/AdviceFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/AdviceFilter.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.servlet;
+package org.apache.shiro.web.servlet;
 
 import java.io.IOException;
 import javax.servlet.FilterChain;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/OncePerRequestFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/OncePerRequestFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/OncePerRequestFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/OncePerRequestFilter.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.servlet;
+package org.apache.shiro.web.servlet;
 
-import org.apache.ki.util.Nameable;
+import org.apache.shiro.util.Nameable;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ProxiedFilterChain.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ProxiedFilterChain.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ProxiedFilterChain.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ProxiedFilterChain.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.servlet;
+package org.apache.shiro.web.servlet;
 
 import java.io.IOException;
 import java.util.List;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ServletContextSupport.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ServletContextSupport.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ServletContextSupport.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/servlet/ServletContextSupport.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.servlet;
+package org.apache.shiro.web.servlet;
 
 import javax.servlet.ServletContext;
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AuthorizationAttributeSourceAdvisor.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/AuthorizationAttributeSourceAdvisor.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.spring.security.interceptor;
+package org.apache.shiro.spring.security.interceptor;
 
 import java.lang.reflect.Method;
 
@@ -26,12 +26,12 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authz.annotation.RequiresAuthentication;
-import org.apache.ki.authz.annotation.RequiresGuest;
-import org.apache.ki.authz.annotation.RequiresPermissions;
-import org.apache.ki.authz.annotation.RequiresRoles;
-import org.apache.ki.authz.annotation.RequiresUser;
-import org.apache.ki.mgt.SecurityManager;
+import org.apache.shiro.authz.annotation.RequiresAuthentication;
+import org.apache.shiro.authz.annotation.RequiresGuest;
+import org.apache.shiro.authz.annotation.RequiresPermissions;
+import org.apache.shiro.authz.annotation.RequiresRoles;
+import org.apache.shiro.authz.annotation.RequiresUser;
+import org.apache.shiro.mgt.SecurityManager;
 
 
 /**
@@ -56,24 +56,24 @@
         return securityManager;
     }
 
-    public void setSecurityManager(org.apache.ki.mgt.SecurityManager securityManager) {
+    public void setSecurityManager(org.apache.shiro.mgt.SecurityManager securityManager) {
         this.securityManager = securityManager;
     }
 
     /**
      * Returns <tt>true</tt> if the method has any Ki annotations, false otherwise.
      * The annotations inspected are:
      * <ul>
      * <li>{@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthentication}</li>
      * <li>{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser}</li>
      * <li>{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest}</li>
      * <li>{@link org.apache.ki.authz.annotation.RequiresRoles RequiresRoles}</li>
      * <li>{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions}</li>
      * </ul>
      *
      * @param method      the method to check for a Ki annotation
      * @param targetClass the class potentially declaring Ki annotations
      * @return <tt>true</tt> if the method has a Ki annotation, false otherwise.
      * @see org.springframework.aop.MethodMatcher#matches(java.lang.reflect.Method, Class)
      */
     public boolean matches(Method method, Class targetClass) {
@@ -56,24 +56,24 @@
 
     /**
-     * Returns <tt>true</tt> if the method has any Ki annotations, false otherwise.
+     * Returns <tt>true</tt> if the method has any Shiro annotations, false otherwise.
      * The annotations inspected are:
      * <ul>
@@ -56,24 +56,24 @@
      * The annotations inspected are:
      * <ul>
-     * <li>{@link org.apache.ki.authz.annotation.RequiresAuthentication RequiresAuthentication}</li>
-     * <li>{@link org.apache.ki.authz.annotation.RequiresUser RequiresUser}</li>
-     * <li>{@link org.apache.ki.authz.annotation.RequiresGuest RequiresGuest}</li>
-     * <li>{@link org.apache.ki.authz.annotation.RequiresRoles RequiresRoles}</li>
-     * <li>{@link org.apache.ki.authz.annotation.RequiresPermissions RequiresPermissions}</li>
+     * <li>{@link org.apache.shiro.authz.annotation.RequiresAuthentication RequiresAuthentication}</li>
+     * <li>{@link org.apache.shiro.authz.annotation.RequiresUser RequiresUser}</li>
+     * <li>{@link org.apache.shiro.authz.annotation.RequiresGuest RequiresGuest}</li>
+     * <li>{@link org.apache.shiro.authz.annotation.RequiresRoles RequiresRoles}</li>
+     * <li>{@link org.apache.shiro.authz.annotation.RequiresPermissions RequiresPermissions}</li>
      * </ul>
      *
@@ -56,24 +56,24 @@
      * </ul>
      *
-     * @param method      the method to check for a Ki annotation
-     * @param targetClass the class potentially declaring Ki annotations
-     * @return <tt>true</tt> if the method has a Ki annotation, false otherwise.
+     * @param method      the method to check for a Shiro annotation
+     * @param targetClass the class potentially declaring Shiro annotations
+     * @return <tt>true</tt> if the method has a Shiro annotation, false otherwise.
      * @see org.springframework.aop.MethodMatcher#matches(java.lang.reflect.Method, Class)
      */

Modified: incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/package-info.java (original)
+++ incubator/shiro/trunk/support/spring/src/main/java/org/apache/shiro/spring/security/interceptor/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,6 +17,6 @@
  * under the License.
  */
 /**
  * Spring AOP support for enabling Ki annotations in Spring-configured applications.
  */
-package org.apache.ki.spring.security.interceptor;
+package org.apache.shiro.spring.security.interceptor;
@@ -17,6 +17,6 @@
  */
 /**
- * Spring AOP support for enabling Ki annotations in Spring-configured applications.
+ * Spring AOP support for enabling Shiro annotations in Spring-configured applications.
  */

Modified: incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/SpringKiFilterTest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/support/spring/src/test/java/org/apache/shiro/spring/SpringKiFilterTest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebRememberMeManager.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebRememberMeManager.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.mgt.AbstractRememberMeManager;
-import org.apache.ki.web.attr.CookieAttribute;
-import org.apache.ki.web.attr.WebAttribute;
-import org.apache.ki.web.servlet.KiHttpServletRequest;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.mgt.AbstractRememberMeManager;
+import org.apache.shiro.web.attr.CookieAttribute;
+import org.apache.shiro.web.attr.WebAttribute;
+import org.apache.shiro.web.servlet.ShiroHttpServletRequest;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -34,8 +34,8 @@
  * Remembers a Subject's identity by using a {@link WebAttribute WebAttribute} instance to retain
  * the identity value between web requests.
  * <p/>
  * This class's default <code>WebAttribute</code> instance is a {@link org.apache.ki.web.attr.CookieAttribute CookieAttribute}, storing
  * the Subject's {@link org.apache.ki.subject.Subject#getPrincipals principals} in a <code>Cookie</code>.  Note that
  * because this class subclasses the <code>AbstractRememberMeManager</code> which already provides serialization and
  * encryption logic, this class utilizes both for added security before setting the cookie value.
  * <p/>
@@ -72,9 +72,9 @@
     public WebRememberMeManager() {
         CookieAttribute<String> attr = new CookieAttribute<String>(DEFAULT_REMEMBER_ME_COOKIE_NAME);
         attr.setCheckRequestParams(false);
         //Peter (Apache Ki developer) said that Jetty didn't like the CookieAttribute.INDEFINITE value
         // (Tomcat was ok with it), so just default to a few years for now.  If anyone doesn't visit a site in 3 years
         // after last login, I doubt any Ki users would mind their end-users to be forced to log in. - LAH.
         attr.setMaxAge(CookieAttribute.ONE_YEAR * 3);
         this.identityAttribute = attr;
     }
@@ -229,7 +229,7 @@
     protected boolean isIdentityRemoved() {
         ServletRequest request = WebUtils.getServletRequest();
         if (request != null) {
-            Boolean removed = (Boolean) request.getAttribute(KiHttpServletRequest.IDENTITY_REMOVED_KEY);
+            Boolean removed = (Boolean) request.getAttribute(ShiroHttpServletRequest.IDENTITY_REMOVED_KEY);
             return removed != null && removed;
         }
         return false;
@@ -34,8 +34,8 @@
  * the identity value between web requests.
  * <p/>
- * This class's default <code>WebAttribute</code> instance is a {@link org.apache.ki.web.attr.CookieAttribute CookieAttribute}, storing
- * the Subject's {@link org.apache.ki.subject.Subject#getPrincipals principals} in a <code>Cookie</code>.  Note that
+ * This class's default <code>WebAttribute</code> instance is a {@link org.apache.shiro.web.attr.CookieAttribute CookieAttribute}, storing
+ * the Subject's {@link org.apache.shiro.subject.Subject#getPrincipals principals} in a <code>Cookie</code>.  Note that
  * because this class subclasses the <code>AbstractRememberMeManager</code> which already provides serialization and
  * encryption logic, this class utilizes both for added security before setting the cookie value.
@@ -72,9 +72,9 @@
         CookieAttribute<String> attr = new CookieAttribute<String>(DEFAULT_REMEMBER_ME_COOKIE_NAME);
         attr.setCheckRequestParams(false);
-        //Peter (Apache Ki developer) said that Jetty didn't like the CookieAttribute.INDEFINITE value
+        //Peter (Apache Shiro developer) said that Jetty didn't like the CookieAttribute.INDEFINITE value
         // (Tomcat was ok with it), so just default to a few years for now.  If anyone doesn't visit a site in 3 years
@@ -72,9 +72,9 @@
         // (Tomcat was ok with it), so just default to a few years for now.  If anyone doesn't visit a site in 3 years
-        // after last login, I doubt any Ki users would mind their end-users to be forced to log in. - LAH.
+        // after last login, I doubt any Shiro users would mind their end-users to be forced to log in. - LAH.
         attr.setMaxAge(CookieAttribute.ONE_YEAR * 3);
         this.identityAttribute = attr;

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebSubjectFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebSubjectFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebUtils.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/WebUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web;
+package org.apache.shiro.web;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
@@ -32,11 +32,11 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.StringUtils;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.StringUtils;
+import org.apache.shiro.util.ThreadContext;
 
 /**
  * Simple utility class for operations used across multiple class hierarchies in the web framework code.
@@ -61,14 +61,14 @@
      * Message displayed when a servlet request or response is not bound to the current thread context when expected.
      */
     private static final String NOT_BOUND_ERROR_MESSAGE =
-            "Make sure WebUtils.bind() is being called. (typically called by KiFilter)  " +
+            "Make sure WebUtils.bind() is being called. (typically called by ShiroFilter)  " +
                     "This could also happen when running integration tests that don't properly call WebUtils.bind().";
 
     public static final String SERVLET_REQUEST_KEY = ServletRequest.class.getName() + "_KI_THREAD_CONTEXT_KEY";
     public static final String SERVLET_RESPONSE_KEY = ServletResponse.class.getName() + "_KI_THREAD_CONTEXT_KEY";
 
     /**
      * {@link org.apache.ki.session.Session Session} key used to save a request and later restore it, for example when redirecting to a
      * requested page after login, equal to <code>kiSavedRequest</code>.
      */
     public static final String SAVED_REQUEST_KEY = "kiSavedRequest";
@@ -319,7 +319,7 @@
      * {@link #getRequiredServletRequest() getRequiredServletRequest()} method always assumes a
      * servlet-only environment.
      * <p/>
      * <b>THIS IS NOT PART OF APACHE KI'S PUBLIC API.</b>  It exists for Ki implementation requirements only.
      * 
      * @return the current thread-bound {@code ServletRequest} or {@code null} if there is not one bound.
      * @since 1.0
@@ -343,7 +343,7 @@
      * from the thread.  To remove it, one must call {@link #unbindServletRequest() unbindServletRequest} instead.
      *
      * @return the ServletRequest bound to the thread.  Never returns null.
      * @throws IllegalStateException if no servlet request is bound in the {@link org.apache.ki.util.ThreadContext ThreadContext}.
      */
     public static ServletRequest getRequiredServletRequest() throws IllegalStateException {
         ServletRequest request = getServletRequest();
@@ -405,7 +405,7 @@
      * {@link #getRequiredServletResponse() getRequiredServletResponse()} method always assumes a
      * servlet-only environment.
      * <p/>
      * <b>THIS IS NOT PART OF APACHE KI'S PUBLIC API.</b>  It exists for Ki implementation requirements only.
      *
      * @return the current thread-bound {@code ServletResponse} or {@code null} if there is not one bound.
      * @since 1.0
@@ -61,14 +61,14 @@
 
     /**
-     * {@link org.apache.ki.session.Session Session} key used to save a request and later restore it, for example when redirecting to a
+     * {@link org.apache.shiro.session.Session Session} key used to save a request and later restore it, for example when redirecting to a
      * requested page after login, equal to <code>kiSavedRequest</code>.
      */
@@ -319,7 +319,7 @@
      * servlet-only environment.
      * <p/>
-     * <b>THIS IS NOT PART OF APACHE KI'S PUBLIC API.</b>  It exists for Ki implementation requirements only.
+     * <b>THIS IS NOT PART OF APACHE SHIRO'S PUBLIC API.</b>  It exists for Shiro implementation requirements only.
      * 
      * @return the current thread-bound {@code ServletRequest} or {@code null} if there is not one bound.
@@ -343,7 +343,7 @@
      *
      * @return the ServletRequest bound to the thread.  Never returns null.
-     * @throws IllegalStateException if no servlet request is bound in the {@link org.apache.ki.util.ThreadContext ThreadContext}.
+     * @throws IllegalStateException if no servlet request is bound in the {@link org.apache.shiro.util.ThreadContext ThreadContext}.
      */
     public static ServletRequest getRequiredServletRequest() throws IllegalStateException {
@@ -405,7 +405,7 @@
      * servlet-only environment.
      * <p/>
-     * <b>THIS IS NOT PART OF APACHE KI'S PUBLIC API.</b>  It exists for Ki implementation requirements only.
+     * <b>THIS IS NOT PART OF APACHE SHIRO'S PUBLIC API.</b>  It exists for Shiro implementation requirements only.
      *
      * @return the current thread-bound {@code ServletResponse} or {@code null} if there is not one bound.

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/AbstractWebAttribute.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/AbstractWebAttribute.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/attr/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 /**
  * Supporting implementation of Ki's concept of a {@link org.apache.ki.web.attr.WebAttribute WebAttribute}, a
  * component that can save and recall an object beyond transient requests.
  */
-package org.apache.ki.web.attr;
+package org.apache.shiro.web.attr;
@@ -17,7 +17,7 @@
  */
 /**
- * Supporting implementation of Ki's concept of a {@link org.apache.ki.web.attr.WebAttribute WebAttribute}, a
+ * Supporting implementation of Shiro's concept of a {@link org.apache.shiro.web.attr.WebAttribute WebAttribute}, a
  * component that can save and recall an object beyond transient requests.
  */

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/IniWebConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/IniWebConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/IniWebConfiguration.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/IniWebConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.config;
+package org.apache.shiro.web.config;
 
 import java.util.ArrayList;
 import java.util.LinkedHashMap;
@@ -34,26 +34,26 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.config.ConfigurationException;
-import org.apache.ki.config.IniConfiguration;
-import org.apache.ki.config.ReflectionBuilder;
-import org.apache.ki.mgt.RealmSecurityManager;
-import org.apache.ki.util.AntPathMatcher;
-import org.apache.ki.util.PatternMatcher;
-import static org.apache.ki.util.StringUtils.split;
-import org.apache.ki.web.DefaultWebSecurityManager;
-import org.apache.ki.web.WebUtils;
-import org.apache.ki.web.filter.PathConfigProcessor;
-import org.apache.ki.web.filter.authc.AnonymousFilter;
-import org.apache.ki.web.filter.authc.BasicHttpAuthenticationFilter;
-import org.apache.ki.web.filter.authc.FormAuthenticationFilter;
-import org.apache.ki.web.filter.authc.UserFilter;
-import org.apache.ki.web.filter.authz.PermissionsAuthorizationFilter;
-import org.apache.ki.web.filter.authz.RolesAuthorizationFilter;
-import org.apache.ki.web.filter.authz.PortFilter;
-import org.apache.ki.web.filter.authz.SslFilter;
-import org.apache.ki.web.servlet.AdviceFilter;
-import org.apache.ki.web.servlet.ProxiedFilterChain;
+import org.apache.shiro.config.ConfigurationException;
+import org.apache.shiro.config.IniConfiguration;
+import org.apache.shiro.config.ReflectionBuilder;
+import org.apache.shiro.mgt.RealmSecurityManager;
+import org.apache.shiro.util.AntPathMatcher;
+import org.apache.shiro.util.PatternMatcher;
+import static org.apache.shiro.util.StringUtils.split;
+import org.apache.shiro.web.DefaultWebSecurityManager;
+import org.apache.shiro.web.WebUtils;
+import org.apache.shiro.web.filter.PathConfigProcessor;
+import org.apache.shiro.web.filter.authc.AnonymousFilter;
+import org.apache.shiro.web.filter.authc.BasicHttpAuthenticationFilter;
+import org.apache.shiro.web.filter.authc.FormAuthenticationFilter;
+import org.apache.shiro.web.filter.authc.UserFilter;
+import org.apache.shiro.web.filter.authz.PermissionsAuthorizationFilter;
+import org.apache.shiro.web.filter.authz.RolesAuthorizationFilter;
+import org.apache.shiro.web.filter.authz.PortFilter;
+import org.apache.shiro.web.filter.authz.SslFilter;
+import org.apache.shiro.web.servlet.AdviceFilter;
+import org.apache.shiro.web.servlet.ProxiedFilterChain;
 
 
 /**
@@ -85,7 +85,7 @@
     /**
      * Returns the <code>PatternMatcher</code> used when determining if an incoming request's path
      * matches a configured filter chain path in the <code>[urls]</code> section.  Unless overridden, the
      * default implementation is an {@link org.apache.ki.util.AntPathMatcher AntPathMatcher}.
      *
      * @return the <code>PatternMatcher</code> used when determining if an incoming request's path
      *         matches a configured filter chain path in the <code>[urls]</code> section.
@@ -98,7 +98,7 @@
     /**
      * Sets the <code>PatternMatcher</code> used when determining if an incoming request's path
      * matches a configured filter chain path in the <code>[urls]</code> section.  Unless overridden, the
      * default implementation is an {@link org.apache.ki.util.AntPathMatcher AntPathMatcher}.
      *
      * @param pathMatcher the <code>PatternMatcher</code> used when determining if an incoming request's path
      *                    matches a configured filter chain path in the <code>[urls]</code> section.
@@ -179,7 +179,7 @@
      * calls this method.
      * <p/>
      * The default implementation merely returns
-     * <code>new {@link org.apache.ki.web.servlet.ProxiedFilterChain FilterChainWrapper(filters, originalChain)}</code>,
+     * <code>new {@link org.apache.shiro.web.servlet.ProxiedFilterChain FilterChainWrapper(filters, originalChain)}</code>,
      * and can be overridden by subclasses for custom creation.
      *
      * @param filters       the configured filter chain for the incoming request application path
@@ -196,7 +196,7 @@
      * <code>false</code> otherwise.
      * <p/>
      * Simply delegates to
-     * <b><code>{@link #getPathMatcher() getPathMatcher()}.{@link org.apache.ki.util.PatternMatcher#matches(String, String) matches(pattern,path)}</code></b>,
+     * <b><code>{@link #getPathMatcher() getPathMatcher()}.{@link org.apache.shiro.util.PatternMatcher#matches(String, String) matches(pattern,path)}</code></b>,
      * but can be overridden by subclasses for custom matching behavior.
      *
      * @param pattern the pattern to match against
@@ -211,7 +211,7 @@
 
     /**
      * Merely returns
-     * <code>WebUtils.{@link org.apache.ki.web.WebUtils#getPathWithinApplication(javax.servlet.http.HttpServletRequest) getPathWithinApplication(request)}</code>
+     * <code>WebUtils.{@link org.apache.shiro.web.WebUtils#getPathWithinApplication(javax.servlet.http.HttpServletRequest) getPathWithinApplication(request)}</code>
      * and can be overridden by subclasses for custom request-to-application-path resolution behavior.
      *
      * @param request the incoming <code>ServletRequest</code>
@@ -223,13 +223,13 @@
 
     /**
      * Creates a new, uninitialized <code>SecurityManager</code> instance that will be used to build up
      * the Ki environment for the web application.
      * <p/>
      * The default implementation simply returns
-     * <code>new {@link org.apache.ki.web.DefaultWebSecurityManager DefaultWebSecurityManager()};</code>
+     * <code>new {@link org.apache.shiro.web.DefaultWebSecurityManager DefaultWebSecurityManager()};</code>
      *
      * @return a new, uninitialized <code>SecurityManager</code> instance that will be used to build up
      *         the Ki environment for the web application.
      */
     protected RealmSecurityManager newSecurityManagerInstance() {
         return new DefaultWebSecurityManager();
@@ -85,7 +85,7 @@
      * Returns the <code>PatternMatcher</code> used when determining if an incoming request's path
      * matches a configured filter chain path in the <code>[urls]</code> section.  Unless overridden, the
-     * default implementation is an {@link org.apache.ki.util.AntPathMatcher AntPathMatcher}.
+     * default implementation is an {@link org.apache.shiro.util.AntPathMatcher AntPathMatcher}.
      *
      * @return the <code>PatternMatcher</code> used when determining if an incoming request's path
@@ -98,7 +98,7 @@
      * Sets the <code>PatternMatcher</code> used when determining if an incoming request's path
      * matches a configured filter chain path in the <code>[urls]</code> section.  Unless overridden, the
-     * default implementation is an {@link org.apache.ki.util.AntPathMatcher AntPathMatcher}.
+     * default implementation is an {@link org.apache.shiro.util.AntPathMatcher AntPathMatcher}.
      *
      * @param pathMatcher the <code>PatternMatcher</code> used when determining if an incoming request's path
@@ -223,13 +223,13 @@
     /**
      * Creates a new, uninitialized <code>SecurityManager</code> instance that will be used to build up
-     * the Ki environment for the web application.
+     * the Shiro environment for the web application.
      * <p/>
      * The default implementation simply returns
@@ -223,13 +223,13 @@
      *
      * @return a new, uninitialized <code>SecurityManager</code> instance that will be used to build up
-     *         the Ki environment for the web application.
+     *         the Shiro environment for the web application.
      */
     protected RealmSecurityManager newSecurityManagerInstance() {

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/WebConfiguration.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/WebConfiguration.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/WebConfiguration.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/WebConfiguration.java Thu Jun 18 03:13:34 2009
@@ -16,17 +16,17 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.config;
+package org.apache.shiro.web.config;
 
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.config.Configuration;
+import org.apache.shiro.config.Configuration;
 
 /**
  * A <code>WebConfiguration</code> configures Ki components in a web-enabled application.
  * <p/>
  * In addition to enabling configuration of a <code>SecurityManager</code>, as required by the parent interface,
  * it also allows configuration of arbitrary filter chains to be executed for any given request or URI/URL.
@@ -16,17 +16,17 @@
 
 /**
- * A <code>WebConfiguration</code> configures Ki components in a web-enabled application.
+ * A <code>WebConfiguration</code> configures Shiro components in a web-enabled application.
  * <p/>
  * In addition to enabling configuration of a <code>SecurityManager</code>, as required by the parent interface,

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/package-info.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/config/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,6 +17,6 @@
  * under the License.
  */
 /**
  * Web-specific implementation extensions to the <code>org.apache.ki.config</code> components.
  */
-package org.apache.ki.web.config;
+package org.apache.shiro.web.config;
@@ -17,6 +17,6 @@
  */
 /**
- * Web-specific implementation extensions to the <code>org.apache.ki.config</code> components.
+ * Web-specific implementation extensions to the <code>org.apache.shiro.config</code> components.
  */

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/AccessControlFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/AccessControlFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/AccessControlFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/AccessControlFilter.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter;
+package org.apache.shiro.web.filter;
 
 import java.io.IOException;
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 
-import org.apache.ki.SecurityUtils;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.web.WebUtils;
+import org.apache.shiro.SecurityUtils;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.web.WebUtils;
 
 /**
  * Superclass for any filter that controls access to a resource and may redirect the user to the login page
@@ -62,7 +62,7 @@
     /**
      * Returns the login URL used to authenticate a user.
      * <p/>
      * Most Ki filters use this url
      * as the location to redirect a user when the filter requires authentication.  Unless overridden, the
      * {@link #DEFAULT_LOGIN_URL DEFAULT_LOGIN_URL} is assumed, which can be overridden via
      * {@link #setLoginUrl(String) setLoginUrl}.
@@ -76,7 +76,7 @@
     /**
      * Sets the login URL used to authenticate a user.
      * <p/>
      * Most Ki filters use this url as the location to redirect a user when the filter requires
      * authentication.  Unless overridden, the {@link #DEFAULT_LOGIN_URL DEFAULT_LOGIN_URL} is assumed.
      *
      * @param loginUrl the login URL used to authenticate a user, used when redirecting users if authentication is required.
@@ -89,7 +89,7 @@
      * Convenience method that acquires the Subject associated with the request.
      * <p/>
      * The default implementation simply returns
-     * {@link org.apache.ki.SecurityUtils#getSubject() SecurityUtils.getSubject()}.
+     * {@link org.apache.shiro.SecurityUtils#getSubject() SecurityUtils.getSubject()}.
      *
      * @param request  the incoming <code>ServletRequest</code>
      * @param response the outgoing <code>ServletResponse</code>
@@ -62,7 +62,7 @@
      * Returns the login URL used to authenticate a user.
      * <p/>
-     * Most Ki filters use this url
+     * Most Shiro filters use this url
      * as the location to redirect a user when the filter requires authentication.  Unless overridden, the
      * {@link #DEFAULT_LOGIN_URL DEFAULT_LOGIN_URL} is assumed, which can be overridden via
@@ -76,7 +76,7 @@
      * Sets the login URL used to authenticate a user.
      * <p/>
-     * Most Ki filters use this url as the location to redirect a user when the filter requires
+     * Most Shiro filters use this url as the location to redirect a user when the filter requires
      * authentication.  Unless overridden, the {@link #DEFAULT_LOGIN_URL DEFAULT_LOGIN_URL} is assumed.
      *

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathConfigProcessor.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/PathConfigProcessor.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/BasicHttpAuthenticationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/BasicHttpAuthenticationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authc;
+package org.apache.shiro.web.filter.authc;
 
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.codec.Base64;
-import org.apache.ki.web.WebUtils;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.web.WebUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -31,7 +31,7 @@
 
 
 /**
  * Requires the requesting user to be {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} for the
  * request to continue, and if they're not, forces the user to login via the HTTP Basic protocol-specific challenge.
  * Upon successful login, they're allowed to continue on to the requested resource/url.
  * <p/>
@@ -54,7 +54,7 @@
  * <p/>
  * <p>The {@link #onAccessDenied(javax.servlet.ServletRequest, javax.servlet.ServletResponse)} method will
  * only be called if the subject making the request is not
- * {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} </p>
+ * {@link org.apache.shiro.subject.Subject#isAuthenticated() authenticated} </p>
  *
  * @author Allan Ditzel
  * @author Les Hazlewood
@@ -122,7 +122,7 @@
      * <p/>
      * Side note: As you can see from the header text, the HTTP Basic specification calls
      * this the authentication 'realm', but we call this the 'applicationName' instead to avoid confusion with
-     * Ki's Realm constructs.
+     * Shiro's Realm constructs.
      *
      * @param applicationName the name to use in the ServletResponse's 'WWW-Authenticate' header.
      */
@@ -31,7 +31,7 @@
 
 /**
- * Requires the requesting user to be {@link org.apache.ki.subject.Subject#isAuthenticated() authenticated} for the
+ * Requires the requesting user to be {@link org.apache.shiro.subject.Subject#isAuthenticated() authenticated} for the
  * request to continue, and if they're not, forces the user to login via the HTTP Basic protocol-specific challenge.
  * Upon successful login, they're allowed to continue on to the requested resource/url.

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/FormAuthenticationFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authc/FormAuthenticationFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/AuthorizationFilter.java (original)
+++ incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/AuthorizationFilter.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.web.filter.authz;
+package org.apache.shiro.web.filter.authz;
 
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.StringUtils;
-import org.apache.ki.web.WebUtils;
-import org.apache.ki.web.filter.AccessControlFilter;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.StringUtils;
+import org.apache.shiro.web.WebUtils;
+import org.apache.shiro.web.filter.AccessControlFilter;
 
 import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
@@ -97,7 +97,7 @@
      * URL.  Otherwise the 401 response is rendered normally</li>
      * </ul>
      * <code><a name="known">[1]</a></code>: A {@code Subject} is 'known' when
      * <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()}</code> is not {@code null},
      * which implicitly means that the subject is either currently authenticated or they have been remembered via
      * 'remember me' services.
      *
@@ -97,7 +97,7 @@
      * </ul>
      * <code><a name="known">[1]</a></code>: A {@code Subject} is 'known' when
-     * <code>subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()}</code> is not {@code null},
+     * <code>subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()}</code> is not {@code null},
      * which implicitly means that the subject is either currently authenticated or they have been remembered via
      * 'remember me' services.

Modified: incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/HostFilter.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/web/src/main/java/org/apache/shiro/web/filter/authz/HostFilter.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================